RequestQueue class

Constructors

RequestQueue(SyncStorage _storage)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enqueue(SyncRequest request) Future<void>
getPendingRequests() Future<List<SyncRequest>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String id) Future<void>
toString() String
A string representation of this object.
inherited
update(SyncRequest request) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited