RetryManager class
Constructors
- RetryManager({int maxRetries = 3, Duration retryDelay = const Duration(seconds: 5)})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxRetries → int
-
final
- retryDelay → Duration
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldRetry(
int currentRetryCount) → bool -
toString(
) → String -
A string representation of this object.
inherited
-
waitBeforeRetry(
) → Future< void>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited