SyncRequest class

Constructors

SyncRequest({required String id, required String method, required String url, Map<String, String>? headers, dynamic body, required DateTime createdAt, int retryCount = 0})
SyncRequest.fromJson(Map<String, dynamic> json)
factory

Properties

body → dynamic
final
createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
id String
final
method String
final
retryCount int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited