HiveStorage class

Implemented types

Constructors

HiveStorage({String boxName = 'offline_sync_requests'})

Properties

boxName String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPendingRequests() Future<List<SyncRequest>>
override
initialize() Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRequest(String id) Future<void>
override
saveRequest(SyncRequest request) Future<void>
override
toString() String
A string representation of this object.
inherited
updateRequest(SyncRequest request) Future<void>
override

Operators

operator ==(Object other) bool
The equality operator.
inherited