SyncStorage class abstract

Implementers

Constructors

SyncStorage()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPendingRequests() Future<List<SyncRequest>>
initialize() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeRequest(String id) Future<void>
saveRequest(SyncRequest request) Future<void>
toString() String
A string representation of this object.
inherited
updateRequest(SyncRequest request) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited