OfflineSync class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pendingRequestsCountStream
→ Stream<
int> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
syncStatusStream
→ Stream<
SyncStatus> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → OfflineSync
-
no setter
Static Methods
-
delete(
{required String url, Map< String, String> ? headers, dynamic data}) → Future<void> -
get(
{required String url, Map< String, String> ? headers}) → Future<void> -
getPendingRequests(
) → Future< List< SyncRequest> > -
initialize(
{SyncStorage? storage, ConflictStrategy conflictStrategy = ConflictStrategy.serverWins, int retryAttempts = 3, Duration retryDelay = const Duration(seconds: 5)}) → Future< void> -
post(
{required String url, Map< String, String> ? headers, dynamic data}) → Future<void> -
put(
{required String url, Map< String, String> ? headers, dynamic data}) → Future<void>